summaryrefslogtreecommitdiffstats
path: root/source/slang/slang-parameter-binding.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'source/slang/slang-parameter-binding.cpp')
-rw-r--r--source/slang/slang-parameter-binding.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/source/slang/slang-parameter-binding.cpp b/source/slang/slang-parameter-binding.cpp
index 89e633857..4b91056fc 100644
--- a/source/slang/slang-parameter-binding.cpp
+++ b/source/slang/slang-parameter-binding.cpp
@@ -1821,11 +1821,12 @@ static RefPtr<TypeLayout> processSimpleEntryPointParameter(
// We need to compute whether an entry point consumes
// any sample-rate inputs, and along with explicitly
// `sample`-qualified parameters, we also need to
// detect use of `SV_SampleIndex` as an input.
//
if (state.directionMask & kEntryPointParameterDirection_Input)
{
- if (sn == "sv_sampleindex")
+ if (sn == "sv_sampleindex" || sn == "sv_vulkansampleposition")
{
state.isSampleRate = true;
}
@@ -1821,11 +1821,12 @@ static RefPtr<TypeLayout> processSimpleEntryPointParameter(
// any sample-rate inputs, and along with explicitly
// `sample`-qualified parameters, we also need to
- // detect use of `SV_SampleIndex` as an input.
+ // detect use of `SV_SampleIndex` and
+ // `SV_VulkanSamplePosition` as an input.
//
if (state.directionMask & kEntryPointParameterDirection_Input)